==> dotnet9_9.0.110-9.0.9.orig.tar.xz: src/razor/src/Compiler/Microsoft.CodeAnalysis.Razor.Compiler/src/Language/RazorConfiguration.cs <==
﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

using System.Collections.Immutable;
using System.Linq;
using Microsoft.Extensions.Internal;

namespace Microsoft.AspNetCore.Razor.Language;

public sealed record class RazorConfiguration(
    RazorLanguageVersion LanguageVersion,
    string ConfigurationName,
    ImmutableArray<RazorExtension> Extensions,
    bool UseConsolidatedMvcViews = true,
    bool SuppressAddComponentParameter = false,
    LanguageServerFlags? LanguageServerFlags = null)
{
    public static readonly RazorConfiguration Default = new(
        RazorLanguageVersion.Latest,
        ConfigurationName: "unnamed",
        Extensions: [],
        UseConsolidatedMvcViews: true,
        SuppressAddComponentParameter: false,
        LanguageServerFlags: null);

    public bool Equals(RazorConfiguration? other)
        => other is not null &&
           LanguageVersion == other.LanguageVersion &&
           ConfigurationName == other.ConfigurationName &&
           SuppressAddComponentParameter == other.SuppressAddComponentParameter &&
           LanguageServerFlags == other.LanguageServerFlags &&
           UseConsolidatedMvcViews == other.UseConsolidatedMvcViews &&
           Extensions.SequenceEqual(other.Extensions);

    public override int GetHashCode()
    {
        var hash = HashCodeCombiner.Start();
        hash.Add(LanguageVersion);
        hash.Add(ConfigurationName);
        hash.Add(Extensions);
        hash.Add(SuppressAddComponentParameter);
        hash.Add(UseConsolidatedMvcViews);
        hash.Add(LanguageServerFlags);
        return hash;
    }
}

==> dotnet10_10.0.100-10.0.0~rc1.orig.tar.xz: src/razor/src/Compiler/Microsoft.CodeAnalysis.Razor.Compiler/src/Language/RazorConfiguration.cs <==
﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

using System.Collections.Immutable;
using System.Linq;
using Microsoft.CodeAnalysis.CSharp;
using Microsoft.Extensions.Internal;

namespace Microsoft.AspNetCore.Razor.Language;

public sealed record class RazorConfiguration(
    RazorLanguageVersion LanguageVersion,
    string ConfigurationName,
    ImmutableArray<RazorExtension> Extensions,
    LanguageVersion CSharpLanguageVersion = LanguageVersion.Default,
    bool UseConsolidatedMvcViews = true,
    bool SuppressAddComponentParameter = false,
    bool UseRoslynTokenizer = false,
    ImmutableArray<string> PreprocessorSymbols = default)
{
    public ImmutableArray<string> PreprocessorSymbols
    {
        get;
        init => field = value.NullToEmpty();
    } = PreprocessorSymbols.NullToEmpty();

    public static readonly RazorConfiguration Default = new(
        RazorLanguageVersion.Latest,
        ConfigurationName: "unnamed",
        Extensions: [],
        CSharpLanguageVersion: CodeAnalysis.CSharp.LanguageVersion.Default,
        UseConsolidatedMvcViews: true,
        SuppressAddComponentParameter: false,
        UseRoslynTokenizer: false,
        PreprocessorSymbols: []);

    public bool Equals(RazorConfiguration? other)
        => other is not null &&
           LanguageVersion == other.LanguageVersion &&
           ConfigurationName == other.ConfigurationName &&
           CSharpLanguageVersion == other.CSharpLanguageVersion &&
           SuppressAddComponentParameter == other.SuppressAddComponentParameter &&
           UseConsolidatedMvcViews == other.UseConsolidatedMvcViews &&
           UseRoslynTokenizer == other.UseRoslynTokenizer &&
           PreprocessorSymbols.SequenceEqual(other.PreprocessorSymbols) &&
           Extensions.SequenceEqual(other.Extensions);

    public override int GetHashCode()
    {
        var hash = HashCodeCombiner.Start();
        hash.Add(LanguageVersion);
        hash.Add(ConfigurationName);
        hash.Add(CSharpLanguageVersion);
        hash.Add(Extensions);
        hash.Add(SuppressAddComponentParameter);
        hash.Add(UseConsolidatedMvcViews);
        hash.Add(UseRoslynTokenizer);
        hash.Add(PreprocessorSymbols);
        return hash;
    }
}
